A phylogenetic tree (phylo object) for 100 simulated Rhinograd species. This tree is used to demonstrate phylogenetic Bayesian structural equation modeling with the becauseR package.
Format
A phylo object (from the ape package) with 100 tips and 99 internal nodes. The tree has been scaled so that the root age is 1.0.
Details
Rhinograds are hypothetical mammals used as examples in phylogenetic comparative methods. This simulated tree represents the evolutionary relationships among 100 Rhinograd species.